fireworks.features package
==========================

Subpackages
-----------

.. toctree::

    fireworks.features.tests

Submodules
----------

fireworks.features.background_task module
-----------------------------------------

.. automodule:: fireworks.features.background_task
    :members:
    :undoc-members:
    :show-inheritance:

fireworks.features.dupefinder module
------------------------------------

.. automodule:: fireworks.features.dupefinder
    :members:
    :undoc-members:
    :show-inheritance:

fireworks.features.fw_report module
-----------------------------------

.. automodule:: fireworks.features.fw_report
    :members:
    :undoc-members:
    :show-inheritance:

fireworks.features.introspect module
------------------------------------

.. automodule:: fireworks.features.introspect
    :members:
    :undoc-members:
    :show-inheritance:

fireworks.features.multi_launcher module
----------------------------------------

.. automodule:: fireworks.features.multi_launcher
    :members:
    :undoc-members:
    :show-inheritance:

fireworks.features.stats module
-------------------------------

.. automodule:: fireworks.features.stats
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: fireworks.features
    :members:
    :undoc-members:
    :show-inheritance:
